==> haskell-ghc-tcplugins-extra-0.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-tcplugins-extra
version: 0.3
id: ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
key: ghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://github.com/clash-lang/ghc-tcplugins-extra
synopsis: Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.
category: Type System
abi: ce7823a6fd180b4f7432a3604d6a13e8
exposed: True
exposed-modules:
    GHC.TcPluginM.Extra
import-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-tcplugins-extra-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/ghc-tcplugins-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ghc-tcplugins-extra-0.3
hs-libraries: HSghc-tcplugins-extra-0.3-BA3RPeS3pLqvaemuhH7UB
depends:
    base-4.11.1.0 ghc-8.4.3
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-8.4.3=b85a78185b88bdae88410d8ef8f69684
haddock-interfaces: /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-tcplugins-extra-0.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-tcplugins-extra
version: 0.3
id: ghc-tcplugins-extra-0.3-D6OYfEB86xkALNc0XsqE2P
key: ghc-tcplugins-extra-0.3-D6OYfEB86xkALNc0XsqE2P
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://github.com/clash-lang/ghc-tcplugins-extra
synopsis: Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.
category: Type System
abi: 6c67a333ed984507df497a6e2bf43954
exposed: True
exposed-modules:
    GHC.TcPluginM.Extra
import-dirs: /usr/lib/ghc-8.6.1/site-local/ghc-tcplugins-extra-0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/ghc-tcplugins-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/ghc-tcplugins-extra-0.3
hs-libraries: HSghc-tcplugins-extra-0.3-D6OYfEB86xkALNc0XsqE2P
depends:
    base-4.12.0.0 ghc-8.6.1
haddock-interfaces: /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
